結果
| 問題 | No.333 門松列を数え上げ |
| コンテスト | |
| ユーザー |
turner18_jp
|
| 提出日時 | 2017-12-12 18:45:55 |
| 言語 | Python3 (3.15.0 + numpy 2.5.4 + scipy 1.18.1 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 20 ms / 2,000 ms |
| + 733µs | |
| コード長 | 143 bytes |
| 記録 | |
| コンパイル時間 | 53 ms |
| コンパイル使用メモリ | 14,976 KB |
| 実行使用メモリ | 10,880 KB |
| 最終ジャッジ日時 | 2026-10-03 07:06:10 |
| 合計ジャッジ時間 | 1,495 ms |
|
ジャッジサーバーID (参考情報) |
judge2_0 / judge4_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| sample | AC * 2 |
| other | AC * 7 |
ソースコード
a, b = map(int, input().split()) ans = 0 if a < b: ans = a - 1 + (b - (a + 1)) elif a > b: ans = 2000000000 - a + (a - (b + 1)) print(ans)
turner18_jp